@@ -15,6 +15,7 @@
 #    under the License.
 
 import copy
+
 import mock
 import testtools
 from testtools.matchers import HasLength
@@ -76,6 +77,10 @@ UPDATED_NODE = copy.deepcopy(NODE1)
 NEW_DRIVER = 'new-driver'
 UPDATED_NODE['driver'] = NEW_DRIVER
 
+CREATE_WITH_UUID = copy.deepcopy(NODE1)
+del CREATE_WITH_UUID['id']
+del CREATE_WITH_UUID['maintenance']
+
 fake_responses = {
     '/v1/nodes':
     {
@@ -455,6 +460,14 @@ class NodeManagerTest(testtools.TestCase):
         self.assertEqual(expect, self.api.calls)
         self.assertTrue(node)
 
+    def test_create_with_uuid(self):
+        node = self.mgr.create(**CREATE_WITH_UUID)
+        expect = [
+            ('POST', '/v1/nodes', {}, CREATE_WITH_UUID),
+        ]
+        self.assertEqual(expect, self.api.calls)
+        self.assertTrue(node)
+
     def test_delete(self):
         node = self.mgr.delete(node_id=NODE1['uuid'])
         expect = [
